@@ -16,9 +16,10 @@ import random
 
 def line_prepender(filename, line):
     with open(filename, 'r+') as f:
+        content = None
         content = f.read()
         f.seek(0, 0)
-        f.write(line.rstrip('\r\n') + '\n' + content)
+        f.write(line + '\n' + content)
 
 
 class IDA:
@@ -93,6 +94,11 @@ class IDA:
             ldrname = config['loader']
 
             ilstrap_data = self.get_data()
+
+            if modname in ilstrap_data['loaders']:
+                old = ilstrap_data['loaders'][modname]
+                os.remove(path.join(self.loaders_dir, old['loader']))
+
             ilstrap_data['loaders'][modname] = config
             self.save_data(ilstrap_data)
 
@@ -105,12 +111,14 @@ class IDA:
 
             # prepend the ilstrap load info into the loader
             loader_loc = path.join(self.loaders_dir, ldrname)
-
+            prefix = "import ilstrapper\n"
             if modsdir:
-                line_prepender(loader_loc, f'ilstrapper.loadmods(\'{modname}\')')
-
-            line_prepender(loader_loc, 'import ilstrapper')
-
+                prefix += f'ilstrapper.loadmods("{modname}")\n'
+            with open(loader_loc, 'r+') as file:
+                fcon = prefix + file.read()
+            os.remove(loader_loc)
+            with open(loader_loc, 'w') as file:
+                file.write(fcon)
             if modsdir:
                 for modulename in listdir(fully_qualified_pathname + path.sep + modsdir):
                     mod_fqp = path.join(fully_qualified_pathname + path.sep + modsdir, modulename)
